Summary:		CORBA Object Request Broker for GNOME-1 compatibility
Name:			ORBit
Epoch:			1
Version:		0.5.17
Release:		51%{?dist}
URL:			https://en.wikipedia.org/wiki/ORBit
Source:			http://ftp.acc.umu.se/pub/gnome/sources/ORBit/0.5/ORBit-0.5.17.tar.bz2 
Patch0:			ORBit-0.5.17-aligned-access.patch
Patch1:			ORBit-underquoted.patch
Patch2:			ORBit-0.5.17-IIOP-weak-symbols.patch
Patch3:			ORBit-0.5.17-multiarch.patch
Patch4:			ORBit-0.5.17-non-weak-symbols.patch
Patch5:			ORBit-0.5.17-make-3.82.patch
Patch6:			ORBit-aarch64.patch
Patch7:			ORBit-0.5.17-format.patch
License:		LGPLv2+ and GPLv2+
BuildRequires:		coreutils
BuildRequires:		flex
BuildRequires:		gcc
BuildRequires:		gettext
BuildRequires:		glib-devel
# Test code in built-in popt library is built statically.
# Using system popt library would be highly likely to introduce regressions in this
# ancient piece of legacy code.
BuildRequires:		glibc-static
BuildRequires:		libtool
BuildRequires:		make
BuildRequires:		pkgconfig
BuildRequires:		sed
# Drop tcp_wrappers support from Fedora 28 onwards:
# https://fedoraproject.org/wiki/Changes/Deprecate_TCP_wrappers
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
BuildRequires:		tcp_wrappers-devel
%endif

# Info directory maintained using file triggers from Fedora 28 onwards
# https://fedoraproject.org/wiki/Packaging:Scriptlets#Texinfo
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
Requires(post):		info
Requires(preun):	info
%endif

%description
ORBit is a high-performance CORBA (Common Object Request Broker Architecture)
ORB (object request broker). It allows programs to send requests and receive
replies from other programs, regardless of the locations of the two programs.
CORBA is an architecture that enables communication between program objects,
regardless of the programming language they are written in or the operating
system they run on.

This package is provided for compatibility with GNOME-1 applications.

%package devel
Summary:	Development libraries, header files and utilities for ORBit
Requires:	glib-devel%{?_isa}
Requires:	indent
Requires:	ORBit%{?_isa} = %{epoch}:%{version}-%{release}
# From Fedora 14, %%{_datadir}/aclocal is included in the filesystem package
%if (0%{?rhel} && 0%{?rhel} <= 6) || (0%{?fedora} && 0%{?fedora} <= 13)
Requires:	%{_datadir}/aclocal
%endif

%description devel
ORBit is a high-performance CORBA (Common Object Request Broker Architecture)
ORB (object request broker) with support for the C language.

This package contains the header files, libraries, and utilities necessary to
build programs that use the ORBit library. It is provided for compatibility
with GNOME-1 applications.

%prep
%setup -q
%patch0 -p1 -b .aligned
%patch1 -p1 -b .underquoted
%patch2 -p1 -b .iiop-non-weak-symbols
%patch3 -p1 -b .multiarch
%patch4 -p1 -b .non-weak-symbols
%patch5 -p1 -b .make-3.82
%patch6 -p1 -b .aarch64
%patch7 -b .format

# Avoid documentation name conflicts
cp -p libIDL/COPYING COPYING.libIDL
mkdir -p docs/libIDL
cp -p libIDL/{AUTHORS,BUGS,ChangeLog,NEWS,README,tstidl.c} docs/libIDL/

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

# %%{?_smp_mflags} removed at release 1:0.5.17-10.2
make

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install

# remove unpackaged files
rm -f %{buildroot}%{_bindir}/ior-decode
rm -f %{buildroot}%{_bindir}/old-name-server
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/lib{IDL,IIOP,ORBit,ORBitCosNaming,ORBitutil}.a
rm -f %{buildroot}%{_datadir}/idl/orbit-1.0/*
rm -f %{buildroot}%{_datadir}/info/dir

# ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

# Info directory maintained using file triggers from Fedora 28
# https://fedoraproject.org/wiki/Packaging:Scriptlets#Texinfo
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
%post devel
/sbin/install-info %{_infodir}/libIDL.info.gz %{_infodir}/dir || :
%preun devel
[ $1 = 0 ] && /sbin/install-info --delete %{_infodir}/libIDL.info.gz %{_infodir}/dir || :
%endif

%files
%if 0%{?_licensedir:1}
%license COPYING COPYING.libIDL
%else
%doc COPYING COPYING.libIDL
%endif
%doc AUTHORS ChangeLog NEWS README TODO
%doc docs/libIDL/
# GPLv2+
%{_bindir}/name-client
%{_bindir}/orbit-name-server
%{_bindir}/orbit-event-server
%{_bindir}/orbit-ird
# LGPLv2+
%{_libdir}/libIDL-0.6.so.*
%{_libdir}/libIIOP.so.*
%{_libdir}/libORBit.so.*
%{_libdir}/libORBitCosNaming.so.*
%{_libdir}/libORBitutil.so.*

%files devel
# GPLv2+
%{_bindir}/orbit-idl
# LGPLv2+
%{_bindir}/libIDL-config
%{_bindir}/orbit-config
%{_includedir}/libIDL-1.0/
%{_includedir}/orbit-1.0/
%{_infodir}/libIDL.info.gz
%{_libdir}/libIDL.so
%{_libdir}/libIDLConf.sh
%{_libdir}/libIIOP.so
%{_libdir}/libORBit.so
%{_libdir}/libORBitCosNaming.so
%{_libdir}/libORBitutil.so
%{_libdir}/libname-server.a
%{_libdir}/liborbit-c-backend.a
%{_libdir}/pkgconfig/ORBit.pc
%{_libdir}/pkgconfig/libIDL.pc
%{_datadir}/aclocal/ORBit.m4
%{_datadir}/aclocal/libIDL.m4

%changelog
* Tue Jun 19 2018 Paul Howarth <paul@city-fan.org> - 1:0.5.17-51
- Info directory maintained using file triggers from Fedora 28
- orbit-resource.sourceforge.net has gone away, so use WikiPedia's ORBit
  article for URL

* Wed Feb 14 2018 Paul Howarth <paul@city-fan.org> - 1:0.5.17-50
- Avoid use of arch-specific build-requires (#1545202)

* Wed Feb  7 2018 Paul Howarth <paul@city-fan.org> - 1:0.5.17-49
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28 onwards
- Drop tcp_wrappers support from Fedora 28 onwards:
  https://fedoraproject.org/wiki/Changes/Deprecate_TCP_wrappers
- Avoid documentation name conflicts with libIDL
- Use forward-looking conditionals
- Drop legacy BuildRoot: and Group: tags
- Drop redundant explicit buildroot cleaning
- BR: glibc-static unconditionally
- Specify all explicitly-used build requirements, one per line

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.5.17-48
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.5.17-47
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.5.17-46
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.5.17-45
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1:0.5.17-44
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-43
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Mar 16 2015 Than Ngo <than@redhat.com> - 1:0.5.17-42
- Bump release and rebuild so that koji-shadow can rebuild it
  against new gcc on secondary arch

* Tue Feb 10 2015 Paul Howarth <paul@city-fan.org> - 1:0.5.17-41
- Build with -fno-strict-aliasing
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-40
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-39
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Nov 21 2013 Paul Howarth <paul@city-fan.org> - 1:0.5.17-38
- Use format strings properly

* Fri Aug 02 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-37
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 25 2013 Paul Howarth <paul@city-fan.org> - 1:0.5.17-36
- Tweak config.guess and config.sub to add aarch64 support (#926289)

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-35
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-34
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-33
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jan  6 2012 Paul Howarth <paul@city-fan.org> - 1:0.5.17-32
- Nobody else likes macros for commands

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-31
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Sep  7 2010 Paul Howarth <paul@city-fan.org> - 1:0.5.17-30
- Fix Makefile issue that kills build with make 3.82 (#631204)

* Mon May 10 2010 Paul Howarth <paul@city-fan.org> - 1:0.5.17-29
- Manual dependency of devel package on pkgconfig not needed from F-11, EL-6
- %%{_datadir}/aclocal included in filesystem package from F-14
- BR: glibc-static for EL-6 onwards

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Apr  9 2009 Paul Howarth <paul@city-fan.org> 1:0.5.17-26
- Fix undefined non-weak symbols in libORBit and libORBitCosNaming
- Use an alternative approach to rpath-fixing - hacking the supplied libtool
  rather than trying to use the system one

* Tue Feb 24 2009 Paul Howarth <paul@city-fan.org> 1:0.5.17-25
- Specify Instruction Set Architecture (%%{?_isa}) in devel package requires
- Buildreq glibc-static for test code in bundled popt library (F-11 onwards)

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.5.17-24
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 13 2008 Paul Howarth <paul@city-fan.org> 1:0.5.17-23
- Rebuild with gcc 4.3.0 for Fedora 9

* Thu Oct 25 2007 Paul Howarth <paul@city-fan.org> 1:0.5.17-22
- Fix multiarch conflicts in -config scripts (#342801)
- Clarify licensing (libs LGPLv2+, binaries GPLv2+)
- Preserve timestamps for files copied from source into installed package
- Build and install using system libtool to avoid bogus rpath on 64-bit arches

* Thu Apr 19 2007 Paul Howarth <paul@city-fan.org> 1:0.5.17-21
- Buildreq pkgconfig, because EL5's glib-devel should require it but doesn't
- Use file-based build dependency on /usr/include/tcpd.h instead of
  tcp_wrappers package, since some distributions have this file in
  tcp_wrappers-devel

* Thu Oct 26 2006 Paul Howarth <paul@city-fan.org> 1:0.5.17-20
- Don't let the scriptlets "fail"

* Mon Aug 28 2006 Paul Howarth <paul@city-fan.org> 1:0.5.17-19
- Fix undefined non-weak symbols in libIIOP.so (#202328)

* Mon Jul 10 2006 Paul Howarth <paul@city-fan.org> 1:0.5.17-18
- Add automake and pkgconfig as deps of devel subpackage (#198246)

* Fri Jul  7 2006 Paul Howarth <paul@city-fan.org> 1:0.5.17-17
- Change summary to indicate that this package is for GNOME-1 compatibility
- Add %%{?dist} tag
- Use Fedora Extras standard buildroot
- Replace PreReq: /sbin/install-info with proper scriptlet dependencies
- Change URL to something that's not 404
- Wrap package descriptions at 80 columns and add notes about the package being
  provided for GNOME-1 compatibility
- Don't use deprecated %%makeinstall macro
- Don't include libIDL/README.win32
- Use fewer globs in the %%files list for this legacy package
- Separate off libIDL docs into their own directory
- Include release number in fully-versioned dependency from devel to main pkg
- Add buildreqs flex and gettext
- Reinstate static libraries that have no dynamic equivalent
- Minor cosmetic changes to spec file

* Mon Mar 20 2006 Matthias Clasen <mclasen@redhat.com> - 1:0.5.17-16
- Fix source URL
- Don't ship static libraries

* Mon Feb 13 2006 Jesse Keating <jkeating@redhat.com> - 1:0.5.17-15.2.2
- rebump for build order issues during double-long bump

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1:0.5.17-15.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1:0.5.17-15.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Mar  2 2005 Mark McLoughlin <markmc@redhat.com> 1:0.5.17-15
- Rebuild with gcc4

* Fri Aug  6 2004 Tim Waugh <twaugh@redhat.com> 1:0.5.17-14
- Fixed another m4 warning.

* Thu Jul 15 2004 Tim Waugh <twaugh@redhat.com> 1:0.5.17-13
- Fixed warnings in shipped m4 file.

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Jun 23 2003 Havoc Pennington <hp@redhat.com> 1:0.5.17-10.4
- rebuild

* Mon Jun  9 2003 Havoc Pennington <hp@redhat.com> 1:0.5.17-10.2
- try removing smp_mflags

* Fri Jun  6 2003 Tim Powers <timp@redhat.com> 1:0.5.17-10.1
- build for RHEL

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Jun  4 2003 Havoc Pennington <hp@redhat.com> 1:0.5.17-9
- a rebuild, to see if it rebuilds

* Tue Jun  3 2003 Jeff Johnson <jbj@redhat.com>
- add explicit epoch's where needed.

* Wed Apr  2 2003 Matt Wilson <msw@redhat.com> 1:0.5.17-8
- added ORBit-0.5.17-aligned-access.patch to fix accesses on some
  non-ia32 architectures (#86347)

* Mon Feb 24 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Sun Feb 23 2003 Tim Powers <timp@redhat.com> 1:0.5.17-6
- add buildprereq on tcp_wrappers

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Sun Dec 01 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- mainframe builds with normal optims again for mainframe

* Thu Nov 21 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- set optflags to "-O0" for mainframe

* Sat Oct 19 2002 Jeremy Katz <katzj@redhat.com>
- update to 0.5.17
- fix to include all files in the build root

* Tue May 28 2002 Havoc Pennington <hp@redhat.com>
- rebuild to see if gcc still doesn't work

* Thu May 16 2002 Alex Larsson <alexl@redhat.com>
- Rebuild

* Wed Feb 27 2002 Havoc Pennington <hp@redhat.com>
- change invocation of auto* such that it will kill the build if it fails
- comment out invocation of auto*, it seems to be pointless

* Wed Feb 27 2002 Havoc Pennington <hp@redhat.com>
- backport to Hampton
- don't invoke autoheader, seems to cause confusion
- don't run strip manually, let RPM deal with it

* Fri Feb  8 2002 Havoc Pennington <hp@redhat.com>
- 0.5.13

* Fri Jan 18 2002 Havoc Pennington <hp@redhat.com>
- fix for automake14

* Tue Nov  6 2001 Jeremy Katz <katzj@redhat.com>
- 0.5.12

* Thu Oct  4 2001 Havoc Pennington <hp@redhat.com>
- 0.5.10

* Fri Sep 21 2001 Havoc Pennington <hp@redhat.com>
- new CVS snap

* Wed Sep 12 2001 Havoc Pennington <hp@redhat.com>
- update to CVS snapshot with headers moved

* Fri Aug 11 2000 Jonathan Blandford <jrb@redhat.com>
- Up Epoch and release

* Tue Jul 25 2000 Elliot Lee <sopwith@redhat.com>
- 0.5.3

* Wed Jul 19 2000 Jonathan Blandford <jrb@redhat.com>
- fixed to work with new cpp.

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Tue Jul 11 2000 Jonathan Blandford <jrb@redhat.com>
- Upgraded to 0.5.2 - a bug fix release.

* Tue Jun 27 2000 Havoc Pennington <hp@redhat.com>
- Trying to build the package for Preston and the build
  system wants a new changelog entry

* Sat Jun 24 2000 Preston Brown <pbrown@redhat.com>
- defattr the devel pkg
- FHS paths

* Fri May 19 2000 Jonathan Blandford <jrb@redhat.com>
- Upgraded to 0.5.1

* Thu Feb  3 2000 Elliot Lee <sopwith@redhat.com> 0.5.0-3
- Strip shared libraries

* Mon Aug 30 1999 Elliot Lee <sopwith@redhat.com> 0.4.94-1
- Spec file fixes from RHL 6.0.

* Wed Jun 2 1999  Jose Mercado <jmercado@mit.edu>
- Fixed configure.in so spec.in could be used.

* Mon Nov 23 1998 Pablo Saratxaga <srtxg@chanae.alphanet.ch>

- improved %%files section, and added use of %%{prefix} and install-info
  (well,... no. The info file has not dir info inside, commented out)
